@@ -650,6 +650,123 @@ layer_separable_conv_2d <- function(object, filters, kernel_size, strides = c(1,
 
 }
 
+
+#' Depthwise 1D convolution
+#'
+#' @details
+#' Depthwise convolution is a type of convolution in which each input channel is
+#' convolved with a different kernel (called a depthwise kernel). You
+#' can understand depthwise convolution as the first step in a depthwise
+#' separable convolution.
+#'
+#' It is implemented via the following steps:
+#'
+#' - Split the input into individual channels.
+#' - Convolve each channel with an individual depthwise kernel with
+#'   `depth_multiplier` output channels.
+#' - Concatenate the convolved outputs along the channels axis.
+#'
+#' Unlike a regular 1D convolution, depthwise convolution does not mix
+#' information across different input channels.
+#'
+#' The `depth_multiplier` argument determines how many filter are applied to one
+#' input channel. As such, it controls the amount of output channels that are
+#' generated per input channel in the depthwise step.
+#'
+#' @param kernel_size An integer, specifying the height and width of the 1D
+#' convolution window. Can be a single integer to specify the same value for
+#' all spatial dimensions.
+#'
+#' @param strides An integer, specifying the strides of the convolution along the
+#' height and width. Can be a single integer to specify the same value for
+#' all spatial dimensions. Specifying any stride value != 1 is incompatible
+#' with specifying any `dilation_rate` value != 1.
+#'
+#' @param padding one of `'valid'` or `'same'` (case-insensitive). `"valid"` means no
+#' padding. `"same"` results in padding with zeros evenly to the left/right
+#' or up/down of the input such that output has the same height/width
+#' dimension as the input.
+#'
+#' @param depth_multiplier The number of depthwise convolution output channels for
+#' each input channel. The total number of depthwise convolution output
+#' channels will be equal to `filters_in * depth_multiplier`.
+#'
+#' @param data_format A string, one of `"channels_last"` (default) or `"channels_first"`.
+#' The ordering of the dimensions in the inputs. `channels_last` corresponds
+#' to inputs with shape `(batch_size, height, width, channels)` while
+#' `channels_first` corresponds to inputs with shape `(batch_size, channels,
+#' height, width)`. It defaults to the `image_data_format` value found in
+#' your Keras config file at `~/.keras/keras.json`. If you never set it, then
+#' it will be 'channels_last'.
+#'
+#' @param dilation_rate A single integer, specifying the dilation rate to use for
+#' dilated convolution. Currently, specifying any `dilation_rate` value != 1
+#' is incompatible with specifying any stride value != 1.
+#'
+#' @param activation Activation function to use. If you don't specify anything, no
+#' activation is applied (see `?activation_relu`).
+#'
+#' @param use_bias Boolean, whether the layer uses a bias vector.
+#'
+#' @param depthwise_initializer Initializer for the depthwise kernel matrix (see
+#' [`initializer_glorot_uniform`]). If NULL, the default initializer
+#' (`"glorot_uniform"`) will be used.
+#'
+#' @param bias_initializer Initializer for the bias vector (see
+#' `keras.initializers`). If NULL, the default initializer ('zeros') will be
+#' used.
+#'
+#' @param depthwise_regularizer Regularizer function applied to the depthwise kernel
+#' matrix (see  [`regularizer_l1()`]).
+#'
+#' @param bias_regularizer Regularizer function applied to the bias vector (see
+#'  [`regularizer_l1()`]).
+#'
+#' @param activity_regularizer Regularizer function applied to the output of the
+#' layer (its 'activation') (see  [`regularizer_l1()`]).
+#'
+#' @param depthwise_constraint Constraint function applied to the depthwise kernel
+#' matrix (see [`constraint_maxnorm()`]).
+#'
+#' @param bias_constraint Constraint function applied to the bias vector (see
+#' [`constraint_maxnorm()`]).
+#'
+#' @param ... standard layer arguments.
+#'
+#' @inheritParams layer_depthwise_conv_2d
+#' @family convolutional layers
+#'
+#' @seealso
+#'   +  <https://www.tensorflow.org/api_docs/python/tf/keras/layers/DepthwiseConv1D>
+#' @export
+layer_depthwise_conv_1d <-
+function(object,
+         kernel_size,
+         strides = 1L,
+         padding = "valid",
+         depth_multiplier = 1L,
+         data_format = NULL,
+         dilation_rate = 1L,
+         activation = NULL,
+         use_bias = TRUE,
+         depthwise_initializer = "glorot_uniform",
+         bias_initializer = "zeros",
+         depthwise_regularizer = NULL,
+         bias_regularizer = NULL,
+         activity_regularizer = NULL,
+         depthwise_constraint = NULL,
+         bias_constraint = NULL,
+         ...) {
+  args <- capture_args(match.call(),
+    list(kernel_size = as.integer,
+         strides = as.integer,
+         depth_multiplier = as.integer,
+         dilation_rate = as.integer),
+    ignore = "object"
+  )
+  create_layer(keras$layers$DepthwiseConv1D, object, args)
+}
+
 #' Depthwise separable 2D convolution.
 #'
 #' Depthwise Separable convolutions consists in performing just the first step
